@@ -2,7 +2,7 @@
 
 from enum import Enum
 
-from loguru import logger
+from loguru import logger as _logger
 
 import tf2mon
 from tf2mon.control import Control, CycleControl
@@ -13,8 +13,8 @@ class LogLevelControl(CycleControl):
     """Cycle logger `level`."""
 
     name = "TOGGLE-LOG-LEVEL"
-    enum = Enum(f"_e_{name}", "INFO DEBUG TRACE")
-    toggle = Toggle(f"_t_{name}", enum)
+    enum = Enum("_e_loglvl", "INFO DEBUG TRACE")
+    toggle = Toggle("_t_loglvl", enum)
     items = {
         enum.INFO: "INFO",  # ""
         enum.DEBUG: "DEBUG",  # "-v"
@@ -36,8 +36,8 @@ class LogLocationControl(CycleControl):
     """Cycle logger `location` format."""
 
     name = "TOGGLE-LOG-LOCATION"
-    enum = Enum(f"_e_{name}", "MOD NAM THM THN FILE NUL")
-    toggle = Toggle(f"_t_{name}", enum)
+    enum = Enum("_e_logloc", "MOD NAM THM THN FILE NUL")
+    toggle = Toggle("_t_logloc", enum)
     items = {
         enum.MOD: "{module}.{function}:{line}",
         enum.NAM: "{name}.{function}:{line}",
@@ -76,4 +76,4 @@ class ResetPaddingControl(Control):
 
     def handler(self, _match) -> None:
         tf2mon.ui.logsink.reset_padding()
-        logger.info("padding reset")
+        _logger.info("padding reset")
