@@ -1,7 +1,5 @@
 """Miscelleneous controls."""
 
-from loguru import logger
-
 import tf2mon
 from tf2mon.control import BoolControl, Control
 from tf2mon.toggle import Toggle
@@ -53,6 +51,10 @@ class ShowKillsControl(BoolControl):
     name = "TOGGLE-SHOW-KILLS"
     toggle = Toggle("kills", [False, True])
 
+    def handler(self, _match) -> None:
+        super().handler(_match)
+        tf2mon.ChatsControl.refresh()
+
 
 class ShowPerksControl(Control):
     """Display perks in journal window."""
@@ -61,7 +63,7 @@ class ShowPerksControl(Control):
 
     def handler(self, _match) -> None:
         tf2mon.ui.show_journal("help", " Perks ".center(80, "-"))
-        for user in [x for x in tf2mon.monitor.users.active_users() if x.perk]:
+        for user in [x for x in tf2mon.users.active_users() if x.perk]:
             tf2mon.ui.show_journal("help", f"{user!r:25} {user.perk}")
 
 
@@ -71,12 +73,12 @@ class JoinOtherTeamControl(Control):
     name = "SWITCH-MY-TEAM"
 
     def handler(self, _match) -> None:
-        if tf2mon.monitor.toggling_enabled:
-            tf2mon.monitor.me.assign_team(tf2mon.monitor.my.opposing_team)
+        if self.toggling_enabled():
+            tf2mon.users.me.assign_team(tf2mon.users.my.opposing_team)
             tf2mon.ui.update_display()
 
     def status(self) -> str:
-        return tf2mon.monitor.my.team.name  # if tf2mon.monitor.my.team else "blu"
+        return tf2mon.users.my.team.name  # if tf2mon.users.my.team else "blu"
 
 
 class ClearQueuesControl(Control):
@@ -88,9 +90,9 @@ class ClearQueuesControl(Control):
     def handler(self, _match) -> None:
         """Handle event."""
 
-        tf2mon.controls["KicksControl"].clear()
+        tf2mon.KicksControl.clear()
         tf2mon.ui.refresh_kicks()
-        tf2mon.controls["SpamsControl"].clear()
+        tf2mon.SpamsControl.clear()
         tf2mon.ui.refresh_spams()
 
 
@@ -99,13 +101,3 @@ class PushControl(Control):
 
     name = "PUSH"
     action = "tf2mon_push"
-
-
-class SingleStepControl(Control):
-    """Start single-stepping."""
-
-    name = "SINGLE-STEP"
-
-    def handler(self, _match) -> None:
-        tf2mon.monitor.admin.start_single_stepping()
-        logger.info("single-step")
