@@ -11,8 +11,8 @@ class SortOrderControl(CycleControl):
     """Cycle scoreboard Sort column."""
 
     name = "TOGGLE-SORT"
-    enum = Enum(f"_e_{name}", "AGE STEAMID CONN K KD USERNAME")
-    toggle = Toggle(f"_t_{name}", enum)
+    enum = Enum("_e_soc", "AGE STEAMID CONN K KD USERNAME")
+    toggle = Toggle("_t_soc", enum)
     items = {
         enum.AGE: lambda user: (user.age, user.username_upper),
         enum.STEAMID: lambda user: (user.steamid.id if user.steamid else 0, user.username_upper),
