@@ -1,7 +1,9 @@
 import re
 
+from loguru import logger
+
 import tf2mon
-from tf2mon.game import GameEvent
+from tf2mon.gameevent import GameEvent
 
 
 class GameCaptureEvent(GameEvent):
@@ -10,11 +12,11 @@ class GameCaptureEvent(GameEvent):
 
     def handler(self, match: re.Match) -> None:
 
-        _leader, username, action, capture_pt, s_teamno = match.groups()
+        username, action, capture_pt, s_teamno = match.groups()
 
         for name in username.split(", "):  # fix: names containing commas
 
-            user = tf2mon.monitor.users[name]
+            user = tf2mon.users[name]
 
             user.assign_teamno(int(s_teamno))
 
@@ -27,5 +29,5 @@ class GameCaptureEvent(GameEvent):
             user.dirty = True
             level += user.team.name
 
-            tf2mon.logger.log(level, f"{user} {capture_pt!r}")
+            logger.log(level, f"{user} {capture_pt!r}")
             user.actions.append(f"{level} {capture_pt!r}")
