@@ -1,9 +1,12 @@
 import re
 
+from loguru import logger
+
 import tf2mon
 from tf2mon.chat import Chat
-from tf2mon.game import GameEvent
+from tf2mon.gameevent import GameEvent
 from tf2mon.player import Player
+from tf2mon.racist import is_racist_text
 
 
 class GameChatEvent(GameEvent):
@@ -18,30 +21,33 @@ class GameChatEvent(GameEvent):
 
     def handler(self, match: re.Match) -> None:
 
-        _leader, _dead, teamflag, username, msg = match.groups()
+        _dead, teamflag, username, msg = match.groups()
 
-        user = tf2mon.monitor.users[username]
+        user = tf2mon.users[username]
         chat = Chat(user, teamflag, msg)
 
         user.chats.append(chat)
-        tf2mon.monitor.chats.append(chat)
-        tf2mon.ui.show_chat(chat)
+        tf2mon.ChatsControl.append(chat)
+
+        level = "TEAMCHAT" if chat.teamflag else "CHAT"
+        if user.team:
+            level += user.team.name
+        logger.log(level, f"{user} {msg}")
 
         # if this is a team chat, then we know we're on the same team, and
         # if one of us knows which team we're on and the other doesn't, we
         # can assign.
 
-        me = my = tf2mon.monitor.me
-        if chat.teamflag and user != me:
+        if chat.teamflag and user != tf2mon.users.me:
             # we're on the same team
             if not user.team:
-                if my.team:
-                    user.assign_team(my.team)
-            elif not my.team:
-                me.assign_team(user.team)
+                if tf2mon.users.my.team:
+                    user.assign_team(tf2mon.users.my.team)
+            elif not tf2mon.users.my.team:
+                tf2mon.users.me.assign_team(user.team)
 
         # inspect msg
-        if tf2mon.monitor.is_racist_text(chat.msg):
+        if is_racist_text(chat.msg):
             user.kick(Player.RACIST)
 
         elif user.is_cheater_chat(chat):
