@@ -1,8 +1,12 @@
 import re
 
+from loguru import logger
+
 import tf2mon
-from tf2mon.game import GameEvent
+from tf2mon.gameevent import GameEvent
+from tf2mon.role import Role, get_role_weapon_state
 from tf2mon.spammer import Spammer
+from tf2mon.user import Kill
 
 
 class GameKillEvent(GameEvent):
@@ -15,10 +19,10 @@ class GameKillEvent(GameEvent):
         # pylint: disable=too-many-branches
         # pylint: disable=too-many-statements
 
-        _leader, s_killer, s_victim, weapon, s_crit = match.groups()
+        s_killer, s_victim, weapon, s_crit = match.groups()
 
-        killer = tf2mon.monitor.users[s_killer]
-        victim = tf2mon.monitor.users[s_victim]
+        killer = tf2mon.users[s_killer]
+        victim = tf2mon.users[s_victim]
 
         killer.last_victim = victim
         victim.last_killer = killer
@@ -67,17 +71,24 @@ class GameKillEvent(GameEvent):
 
         # subtotal opponents by weapon_state -----------------------------------
 
-        if role := tf2mon.monitor.role_by_weapon.get(weapon):
+        crit = bool(s_crit)
+        role, weapon_state = get_role_weapon_state(killer.role, weapon, crit, killer.perk)
+        if role:
             killer.role = role
-            if killer.role == tf2mon.monitor.sniper_role:
+            killer.weapon_state = weapon_state
+            if killer.role == Role.sniper:
                 killer.nsnipes += 1
         else:
             role = killer.role
             if weapon not in ("player", "world"):
-                tf2mon.logger.error(f"cannot map {weapon} for {killer} {role}")
+                logger.error(f"cannot map {weapon} for {killer} {role}")
 
-        crit = bool(s_crit)
-        weapon_state = role.get_weapon_state(weapon, crit, killer.perk)
+        kill = Kill(killer, victim)
+        killer.kills.append(kill)
+        victim.deaths.append(kill)
+
+        if not role and weapon not in ("player", "world"):
+            logger.error(f"cannot map {weapon} for {killer} {role}")
 
         if victim.key not in killer.nkills_by_opponent_by_weapon:
             # contains a hash of counts by weapon_state
@@ -91,7 +102,7 @@ class GameKillEvent(GameEvent):
         if killer.team:
             level += killer.team.name
 
-        tf2mon.logger.log(
+        logger.log(
             level,
             "killer {!r} victim {!r} weapon {!r}",
             killer.moniker,
@@ -99,19 +110,10 @@ class GameKillEvent(GameEvent):
             weapon_state,
         )
 
-        if tf2mon.controls["ShowKillsControl"].value:
-            level = "KILL"
-            if killer.team:
-                level += killer.team.name
-            tf2mon.ui.show_journal(
-                level,
-                f"         {killer.moniker!r:25} killed {victim.moniker!r:25} {weapon_state!r}",
-            )
-
-        if killer == tf2mon.monitor.me:
-            if tf2mon.controls["TauntFlagControl"].value:
+        if killer == tf2mon.users.me:
+            if tf2mon.TauntFlagControl.value:
                 self.spammer.taunt(victim, weapon, crit)
-        elif victim == tf2mon.monitor.me and tf2mon.controls["ThroeFlagControl"].value:
+        elif victim == tf2mon.users.me and tf2mon.ThroeFlagControl.value:
             self.spammer.throe(killer, weapon, crit)
 
         if not victim.team and killer.team:
