@@ -1,7 +1,9 @@
 import re
 
+from loguru import logger
+
 import tf2mon
-from tf2mon.game import GameEvent
+from tf2mon.gameevent import GameEvent
 from tf2mon.steamid import parse_steamid
 from tf2mon.user import Team
 
@@ -18,7 +20,7 @@ class GameLobbyEvent(GameEvent):
         # this will not be called for games on local server with bots
         # or community servers; only on valve matchmaking servers.
 
-        _leader, s_steamid, teamname = match.groups()
+        s_steamid, teamname = match.groups()
 
         if not (steamid := parse_steamid(s_steamid)):
             return  # invalid
@@ -28,16 +30,16 @@ class GameLobbyEvent(GameEvent):
         elif teamname == "TF_GC_TEAM_DEFENDERS":
             team = Team.RED
         else:
-            tf2mon.logger.critical(f"bad teamname {teamname!r} steamid {steamid}")
+            logger.critical(f"bad teamname {teamname!r} steamid {steamid}")
             return
 
-        if old_team := tf2mon.monitor.users.teams_by_steamid.get(steamid):
+        if old_team := tf2mon.users.teams_by_steamid.get(steamid):
             # if we've seen this steamid before...
             if old_team != team:
                 # ...and
-                tf2mon.logger.warning(f"{steamid.id} change team `{old_team}` to `{team}`")
+                logger.warning(f"{steamid.id} change team `{old_team}` to `{team}`")
         else:
-            tf2mon.logger.log("ADDLOBBY", f"{team} {steamid.id}")
+            logger.log("ADDLOBBY", f"{team} {steamid.id}")
 
         #
-        tf2mon.monitor.users.teams_by_steamid[steamid] = team
+        tf2mon.users.teams_by_steamid[steamid] = team
