@@ -1,7 +1,9 @@
 import re
 
+from loguru import logger
+
 import tf2mon
-from tf2mon.game import GameEvent
+from tf2mon.gameevent import GameEvent
 
 
 class GamePerkOnEvent(GameEvent):
@@ -12,11 +14,11 @@ class GamePerkOnEvent(GameEvent):
 
     def handler(self, match: re.Match) -> None:
 
-        _leader, username, perk = match.groups()
-        user = tf2mon.monitor.users[username]
+        username, perk = match.groups()
+        user = tf2mon.users[username]
         user.perk = perk
         user.dirty = True
-        tf2mon.logger.log("PERK-ON", f"{user} {perk!r}")
+        logger.log("PERK-ON", f"{user} {perk!r}")
 
 
 class GamePerkOff1Event(GameEvent):
@@ -25,23 +27,23 @@ class GamePerkOff1Event(GameEvent):
 
     def handler(self, match: re.Match) -> None:
 
-        _leader, username = match.groups()
-        user = tf2mon.monitor.users[username]
+        (username,) = match.groups()
+        user = tf2mon.users[username]
         user.perk = None
         user.dirty = True
-        tf2mon.logger.log("PERK-OFF", f"{user} {user.perk!r}")
+        logger.log("PERK-OFF", f"{user} {user.perk!r}")
 
 
 class GamePerkOff2Event(GameEvent):
 
     pattern = r"[0-9A-F]{6}\[RTD\] Your perk has worn off."
 
-    def handler(self, match: re.Match) -> None:
+    def handler(self, _match: re.Match) -> None:
 
-        user = tf2mon.monitor.me
+        user = tf2mon.users.me
         user.perk = None
         user.dirty = True
-        tf2mon.logger.log("PERK-OFF", f"{user} {user.perk!r}")
+        logger.log("PERK-OFF", f"{user} {user.perk!r}")
 
 
 class GamePerkChangeEvent(GameEvent):
@@ -50,6 +52,6 @@ class GamePerkChangeEvent(GameEvent):
 
     def handler(self, match: re.Match) -> None:
 
-        _leader, username = match.groups()
-        user = tf2mon.monitor.users[username]
-        tf2mon.logger.debug(f"{user} changed class")
+        (username,) = match.groups()
+        user = tf2mon.users[username]
+        logger.debug(f"{user} changed class")
