@@ -3,6 +3,7 @@
 from loguru import logger
 
 import tf2mon
+from tf2mon.pkg import APPNAME
 from tf2mon.toggle import Cycle
 
 
@@ -94,21 +95,21 @@ class Spammer:
 
         m = messages.cycle.format(
             user=user.moniker,
-            duel=tf2mon.monitor.my.duel_as_str(user),
+            duel=tf2mon.users.my.duel_as_str(user),
             weapon=weapon,
             killed=self._killed.cycle,
             insult=self._insults.cycle,
         )
-        tf2mon.controls["SpamsControl"].push("say " + m + suffix)
+        tf2mon.SpamsControl.push("say " + m + suffix)
 
     def spam(self, spamno):
         """Respond to SPAM command."""
 
         if spamno == 1:
-            msg = str("say Real-time stats brought to you by " f"{tf2mon.APPNAME} bot detector")
+            msg = str("say Real-time stats brought to you by " f"{APPNAME} bot detector")
 
         else:
             logger.critical(f"bad spamno {spamno!r}")
             return
 
-        tf2mon.controls["SpamsControl"].pushleft(msg)
+        tf2mon.SpamsControl.pushleft(msg)
