@@ -1,14 +1,19 @@
 """A user of the game."""
 
 import re
+import time
+from dataclasses import dataclass, field
 from enum import Enum
-from typing import NewType
+from typing import Iterator, List, NewType
 
-from fuzzywuzzy import fuzz
 from loguru import logger
 
 import tf2mon
+from tf2mon.chat import Chat
 from tf2mon.player import Player
+from tf2mon.racist import clean_username
+from tf2mon.role import Role
+from tf2mon.steamplayer import SteamPlayer
 
 UserKey = NewType("UserKey", str)
 WeaponState = NewType("WeaponState", str)
@@ -21,18 +26,41 @@ class Team(Enum):
     BLU = 3
 
 
-class UserState(Enum):
-    """Valid states."""
+@dataclass
+class UserStats:
+    """Snapshot of stats at some point in time."""
 
-    ACTIVE = "A"
-    INACTIVE = "I"
+    # pylint: disable=too-many-instance-attributes
+    user: "User"
+    last_killer: "User"
+    last_victim: "User"
+    role: Role
+    weapon_state: WeaponState
+    nkills: int
+    ndeaths: int
+    kdratio: float
+    # timestamp: float
+
+
+@dataclass
+class Kill:
+    """A Kill."""
+
+    killer: UserStats  # snapshot of killer at time of kill
+    victim: UserStats  # snapshot of victim at time of death
+    timestamp: float = field(default=None)
+
+    def __post_init__(self):
+        """Initialize data and other attributes."""
+
+        if not self.timestamp:
+            self.timestamp = time.time()
 
 
 class User:
     """A user of the game."""
 
     # pylint: disable=too-many-instance-attributes
-    # pylint: disable=too-many-statements
 
     _re_cheater_chats = re.compile(
         "|".join(
@@ -43,6 +71,8 @@ class User:
         )
     )
 
+    _max_status_checks = 2
+
     def is_cheater_chat(self, chat):
         """Return True first time chat appears to be from a cheater."""
 
@@ -51,17 +81,11 @@ class User:
         self.cheater_chat_seen = self._re_cheater_chats.search(chat.msg)
         return self.cheater_chat_seen
 
-    def __init__(self, username):
+    def __init__(self, username: str):
         """Create `User`."""
 
         self.username = username.replace(";", ".")
-
-        if m := tf2mon.monitor._re_racist.search(self.username):
-            self._clean_username = (
-                m.string[: m.start()] + str("n" * (m.end() - m.start())) + m.string[m.end() :]
-            )
-        else:
-            self._clean_username = self.username
+        self._clean_username = clean_username(self.username)
 
         # too strict?
         if "\u0e31" in self.username:
@@ -79,25 +103,27 @@ class User:
         self.last_scoreboard_line = True
         self.dirty = True
 
-        self.state = UserState.ACTIVE
         self.n_status_checks = 0
         self.nsnipes = 0
-        self.role = tf2mon.monitor.unknown_role
+        self.role = Role.unknown
+        self.weapon_state: WeaponState = None
         self.ncaptures = 0
         self.ndefenses = 0
-        self.chats = []
+        self.chats: List[Chat] = []
         self.display_level = None
         self.selected = False
         self.perk = None
 
         #
-        self.opponents: dict[User, User] = {}
-        self.victims: dict[User, User] = {}
-        self.killers: dict[User, User] = {}
+        self.opponents: dict[UserKey, User] = {}
+        self.victims: dict[UserKey, User] = {}
+        self.killers: dict[UserKey, User] = {}
 
         self.last_killer: User = None
         self.last_victim: User = None
 
+        self.kills: List[Kill] = []
+        self.deaths: List[Kill] = []
         self.nkills = 0
         self.ndeaths = 0
         self.kdratio: float = 0
@@ -109,10 +135,10 @@ class User:
         self.nkills_by_opponent_by_weapon: dict[UserKey, dict[WeaponState, int]] = {}
 
         # list of non-kill actions performed, like capture/defend.
-        self.actions = []
+        self.actions: List[str] = []
 
         #
-        self.steamplayer = None
+        self.steamplayer: SteamPlayer = None
         self.age = 0
         self.player: Player = None
 
@@ -126,14 +152,8 @@ class User:
         # notify the operator asap to `TF2MON-PUSH` steamids to us.
         # Careful, this might be a legitimate name-change, not a cheating name-stealer.
 
-        self.cloner = None  # when this user is being cloned
-        self.clonee = None  # when this user is the name-stealing clone
-
-        if self._is_cheater_name(self.username):
-            self.kick(Player.CHEATER)
-
-        if tf2mon.monitor.is_racist_text(self.username):
-            self.kick(Player.RACIST)
+        self.cloner: User = None  # when this user is being cloned
+        self.clonee: User = None  # when this user is the name-stealing clone
 
         self.cheater_chat_seen = False
 
@@ -143,6 +163,12 @@ class User:
 
         return f"{self.userid}-{self._clean_username[:15]}"
 
+    @property
+    def is_active(self) -> bool:
+        """Return True if user is active."""
+
+        return self.n_status_checks < self._max_status_checks
+
     @property
     def points(self):
         """Return number of points scored."""
@@ -159,7 +185,7 @@ class User:
     def moniker(self):
         """Return name, optionally including his kill/death ratio."""
 
-        if not tf2mon.controls["ShowKDControl"].value:
+        if not tf2mon.ShowKDControl.value:
             return self._clean_username
 
         # pylint: disable=consider-using-f-string
@@ -183,6 +209,49 @@ class User:
         team = f"{self.team.name}:" if self.team else ""
         return f"{team}{self.userid}={self.username!r}"
 
+    def snap_stats(self) -> UserStats:
+        """Take and return a snapshot of current stats."""
+
+        return UserStats(
+            self,
+            self.last_killer,
+            self.last_victim,
+            self.role,
+            self.weapon_state,
+            self.nkills,
+            self.ndeaths,
+            self.kdratio,
+        )
+
+    def format_user_stats(self) -> Iterator[str]:
+        """Return most recent kill and most recent death in reverse chronological order."""
+
+        kills: list[Kill] = []
+
+        if len(self.kills) > 0:
+            kills.append(self.kills[-1])
+        if len(self.deaths) > 0:
+            kills.append(self.deaths[-1])
+
+        for kill in sorted(kills, key=lambda x: -x.timestamp):
+            if self == kill.killer:
+                opponent = kill.victim
+                label = "[last-Victim]"
+            else:
+                opponent = kill.killer
+                label = "[last-Killer]"
+
+            yield " ".join(
+                [
+                    time.strftime("%T", time.localtime(kill.timestamp)),
+                    label,
+                    self.duel_as_str(opponent, formatted=True),
+                    "vs",
+                    f"{opponent.username:20.20}",
+                    opponent.weapon_state or "",
+                ]
+            )
+
     def assign_teamno(self, teamno):
         """Assign this user to `teamno`."""
 
@@ -222,13 +291,13 @@ class User:
             if not self.team:
                 self.assign_team(opponent.opposing_team)
 
-    def vet(self):
+    def vet(self) -> None:
         """Vet this player, whose `steamid` has just been obtained."""
 
         assert self.steamid
         self.dirty = True
 
-        self.steamplayer = tf2mon.monitor.steam_web_api.fetch_steamid(self.steamid.id)
+        self.steamplayer = tf2mon.steam_web_api.fetch_steamid(self.steamid.id)
         if self.steamplayer.is_gamebot:
             self.steamplayer.personaname = self.username
             self.pending_attrs = []
@@ -257,7 +326,7 @@ class User:
         # Have we tried to kick them, but had to spool the work because
         # `steamid` wasn't available yet?
         if self.pending_attrs:
-            self.player = self._new_player(self.steamid.id, self.pending_attrs, self.username)
+            self.player = Player.new_player(self.steamid.id, self.pending_attrs, self.username)
             # bobo1
             self.display_level = self.player.display_level
             logger.log(self.display_level, f"{self} created {self.player}")
@@ -266,15 +335,6 @@ class User:
             if self.player.is_banned:
                 self.do_kick()
 
-    @staticmethod
-    def _new_player(steamid: int, attrs: list[str], name: str) -> Player:
-        """Create, insert and return new `Player`."""
-
-        player = Player(steamid)
-        player.setattrs(attrs)
-        player.track_appearance(name)
-        return player
-
     def kick(self, attr):
         """Kick this user."""
 
@@ -283,8 +343,8 @@ class User:
             self.pending_attrs.append(attr)
             self.display_level = attr.upper()
             logger.log(self.display_level, f"{self} needs steamid, Press KP_DOWNARROW to PUSH")
-            tf2mon.ui.notify_operator = True
-            tf2mon.ui.sound_alarm = True
+            tf2mon.notify_operator = True
+            tf2mon.sound_alarm = True
             return
 
         if self.player:
@@ -295,7 +355,7 @@ class User:
             else:
                 logger.info(f"{self} player {self.player} already {attr}")
         else:
-            self.player = self._new_player(
+            self.player = Player.new_player(
                 self.steamid.id, [attr] + self.pending_attrs, self.username
             )
             self.display_level = self.player.display_level
@@ -321,35 +381,5 @@ class User:
         cmd = f"CALLVOTE KICK {self.userid}"
         msg += f", {cmd}"
 
-        tf2mon.controls["KicksControl"].push(msg)
-        tf2mon.controls["KicksControl"].push(cmd)
-
-    _re_cheater_names = re.compile(
-        "|".join(
-            [
-                r"^(\(\d+\))?Sydney",
-                r"Swonk Bot",
-                r"spoooky braaaap",
-                r"Bot Removal Service",
-                r"^\[g0tb0t\]Church-of-myg0t",
-            ]
-        )
-    )
-
-    def _is_cheater_name(self, name):
-
-        if self._re_cheater_names.search(name):
-            return True
-
-        for user in [
-            x for x in tf2mon.monitor.users.active_users() if x.steamplayer and not x.player
-        ]:
-            ratio = fuzz.ratio(name, user.username)
-            if ratio > 80:
-                logger.log("FUZZ", f"ratio {ratio} {name!r} vs {user.username!r}")
-                # Careful, this might be a legitimate name-change, not a cheating name-stealer.
-                user.cloner = self  # point the original user to the clone
-                self.clonee = user  # point the clone to the original user
-                return True
-
-        return False
+        tf2mon.KicksControl.push(msg)
+        tf2mon.KicksControl.push(cmd)
